@@ -1,5 +1,6 @@
 # $id$
 #
+from __future__ import with_statement
 '''Simple, elegant HTML generation.
 
 Constructing your HTML
@@ -28,7 +29,9 @@ later using the tag's ``.text()`` method (note it is assumed that a fresh
 
 Any HTML-specific characters (``<>&"``) in the text will be escaped for HTML
 safety as appropriate unless ``escape=False`` is passed. Note also that the
-top-level ``HTML`` object adds newlines between tags by default.
+top-level ``HTML`` object adds newlines between tags by default. Finally in
+the above you'll see an empty paragraph tag - tags with no contents get no
+closing tag.
 
 If the tag should have sub-tags you have two options. You may either add
 the sub-tags directly on the tag::
@@ -96,6 +99,8 @@ How generation works
 
 The HTML document is generated when the ``HTML`` instance is "stringified".
 This could be done either by invoking ``str()`` on it, or just printing it.
+It may also be returned directly as the "iterable content" from a WSGI app
+function.
 
 You may also render any tag or sub-tag at any time by stringifying it.
 
@@ -107,9 +112,6 @@ even if it's just a single space character.
 Rendering doesn't affect the HTML document's state, so you can add to or
 otherwise manipulate the HTML after you've stringified it.
 
-The HTML instance may also be returned directly as the "iterable content"
-in a WSGI app function.
-
 
 Creating XHTML
 --------------
@@ -129,6 +131,8 @@ with the appropriate XHTML minimized tag syntax. For example::
 Version History (in Brief)
 --------------------------
 
+- 1.7 added Python 2.5 compatibility and escape argument to tag
+  construction
 - 1.6 added .raw_text() and and WSGI compatibility
 - 1.5 added XHTML support
 - 1.3 added more documentation, more tests
@@ -142,7 +146,7 @@ This code is copyright 2009 eKit.com Inc (http://www.ekit.com/)
 See the end of the source file for the license of use.
 XHTML support was contributed by Michael Haubenwallner.
 '''
-__version__ = '1.6'
+__version__ = '1.7'
 
 import unittest
 import cgi
@@ -195,8 +199,12 @@ class HTML(object):
         return self.text(text, escape=False)
     def __call__(self, *content, **kw):
         # customising a tag with content or attributes
+        escape = kw.pop('escape', True)
         if content:
-            self.content = map(cgi.escape, content)
+            if escape:
+                self.content = map(cgi.escape, content)
+            else:
+                self.content = content
         if 'newlines' in kw:
             # special-case to allow control over newlines
             self.newlines = kw.pop('newlines')
